# Telemetry data

We collect the time of functions to run, the length of the input and output for LLM. Currenly, there is no switcher to turn off collecting metrics, will be added later. `app/telemetry` module is responsible for telemetry.
